@@ -4,11 +4,12 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.1050';
+our $VERSION = '0.1051';
 
-use Carp       ();
-use File::Spec ();
-use Exporter   ();
+use Carp        ();
+use File::Spec  ();
+use Exporter    ();
+use Digest::MD5 ();
 
 use Text::Xslate::Util qw(
     $DEBUG
@@ -55,7 +56,7 @@ BEGIN {
 
     my $cache_dir = '.xslate_cache';
     foreach my $d($ENV{HOME}, File::Spec->tmpdir) {
-        if(-d $d && -w _) {
+        if(defined($d) and -d $d and -w _) {
             $cache_dir = File::Spec->catfile($d, '.xslate_cache');
             last;
         }
@@ -204,7 +205,7 @@ sub find_file {
     my $orig_mtime;
     my $cache_mtime;
     foreach my $p(@{$self->{path}}) {
-        print STDOUT "  find_file: $p / $file\n" if _DUMP_LOAD;
+        print STDOUT "  find_file: $p / $file ...\n" if _DUMP_LOAD;
         if(ref $p eq 'HASH') { # virtual path
             defined(my $content = $p->{$file}) or next;
             $fullpath   = \$content;
@@ -218,10 +219,7 @@ sub find_file {
 
         # $file is found
 
-        $cachepath   = File::Spec->catfile(
-            $self->{cache_dir},
-            (ref($p) ? 'VPATH' : $p),
-            $file . 'c');
+        $cachepath = $self->_cache_path($p, $file);
         $cache_mtime = (stat($cachepath))[_ST_MTIME]; # may fail, but doesn't matter
         last;
     }
@@ -241,6 +239,16 @@ sub find_file {
     };
 }
 
+sub _cache_path {
+    my($self, $path, $file) = @_;
+
+    $path = 'VPATH' if ref $path;
+    return  do {
+        my $d = Digest::MD5::md5_hex($path);
+        File::Spec->catfile($self->{cache_dir}, $d, $file . "c");
+    };
+}
+
 sub load_file {
     my($self, $file, $mtime) = @_;
 
@@ -332,7 +340,7 @@ sub _load_compiled {
     if($self->{cache} >= 2) {
         # threshold is the most latest modified time of all the related caches,
         # so if the cache level >= 2, they seems always fresh.
-        $threshold = '+inf';
+        $threshold = 9**9**9;
     }
     else {
         $threshold ||= $fi->{cache_mtime};
@@ -340,7 +348,7 @@ sub _load_compiled {
     # see also tx_load_template() in xs/Text-Xslate.xs
     if(!( defined($fi->{cache_mtime}) and $self->{cache} >= 1
             and $threshold >= $fi->{orig_mtime} )) {
-        printf "  _load_compiled: no fresh cache: %s", Text::Xslate::Util::p($fi) if _DUMP_LOAD;
+        printf "  _load_compiled: no fresh cache: %s, %s", $threshold, Text::Xslate::Util::p($fi) if _DUMP_LOAD;
         $fi->{cache_mtime} = undef;
         return undef;
     }
@@ -383,7 +391,7 @@ sub _load_compiled {
         if($name eq 'depend') {
             my $dep_mtime = (stat $value)[_ST_MTIME];
             if(!defined $dep_mtime) {
-                $dep_mtime = '+inf'; # force reload
+                $dep_mtime = 9**9**9; # force reload
                 Carp::carp("Xslate: Failed to stat $value (ignored): $!");
             }
             if($dep_mtime > $threshold){
@@ -423,10 +431,7 @@ sub _magic_token {
     );
 
     if(ref $fullpath) { # ref to content string
-        require 'Digest/MD5.pm'; # we don't want to create its namespace
-        my $md5 = Digest::MD5->new();
-        $md5->add(${$fullpath});
-        $fullpath = 'VPATH:' . $md5->hexdigest();
+        $fullpath = 'VPATH:' . Digest::MD5::md5_hex(${$fullpath})
     }
 
     return sprintf $XSLATE_MAGIC,
@@ -491,7 +496,7 @@ Text::Xslate - High performance template engine
 
 =head1 VERSION
 
-This document describes Text::Xslate version 0.1050.
+This document describes Text::Xslate version 0.1051.
 
 =head1 SYNOPSIS
 
@@ -594,7 +599,7 @@ but is more powerful.
 
 This mechanism is also called as template inheritance.
 
-=head3 High extensibility
+=head3 Easy to enhance
 
 Xslate is highly extensible. You can add functions and methods to the template
 engine and even add a new syntax via extending the parser.
@@ -935,6 +940,10 @@ Xslate command:
 
 L<xlsate>
 
+The Xslate web site:
+
+L<http://xslate.org/>
+
 Other template modules that Xslate is influenced by:
 
 L<Text::MicroTemplate>
